@@ -41,8 +41,8 @@ public:
     {
         QList<MailBoxDescriptor> result;
 
-        foreach (const QByteArray &namespaceItem, namespaceList) {
-            ImapStreamParser parser(Q_NULLPTR);
+        for (const QByteArray &namespaceItem : namespaceList) {
+            ImapStreamParser parser(nullptr);
             parser.setData(namespaceItem);
 
             try {
@@ -55,7 +55,7 @@ public:
                 descriptor.separator = QLatin1Char(parts[1][0]);
 
                 result << descriptor;
-            } catch (KIMAP::ImapParserException e) {
+            } catch (const KIMAP::ImapParserException &e) {
                 qCWarning(KIMAP_LOG) << "The stream parser raised an exception during namespace list parsing:" << e.what();
                 qCWarning(KIMAP_LOG) << "namespacelist:" << namespaceList;
             }
@@ -103,11 +103,11 @@ QList<MailBoxDescriptor> NamespaceJob::sharedNamespaces() const
 bool NamespaceJob::containsEmptyNamespace() const
 {
     Q_D(const NamespaceJob);
-    QList<MailBoxDescriptor> completeList = d->personalNamespaces
+    const QList<MailBoxDescriptor> completeList = d->personalNamespaces
                                             + d->userNamespaces
                                             + d->sharedNamespaces;
 
-    foreach (const MailBoxDescriptor &descriptor, completeList) {
+    for (const MailBoxDescriptor &descriptor : completeList) {
         if (descriptor.name.isEmpty()) {
             return true;
         }
